=================
Plasmidsimilarity
=================


.. image:: https://img.shields.io/pypi/v/Plasmidsimilarity.svg
        :target: https://pypi.python.org/pypi/Plasmidsimilarity

.. image:: https://img.shields.io/travis/casperjamin/Plasmidsimilarity.svg
        :target: https://travis-ci.com/casperjamin/Plasmidsimilarity

.. image:: https://readthedocs.org/projects/Plasmidsimilarity/badge/?version=latest
        :target: https://Plasmidsimilarity.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Set of scripts to compare plasmid sequences and its gene content


* Free software: BSD license
* Documentation: https://Plasmidsimilarity.readthedocs.io.


Installation
------------
to install::
    
    git clone https://github.com/casperjamin/Plasmidsimilarity
    cd Plasmidsimilarity
    pip install .




Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage


This work was supported by the Dutch workgroup Molecular typing for infectious diseases, the WMDI.
